/*******************************************************************************
* File Name: Busy.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Busy.h"

static Busy_BACKUP_STRUCT  Busy_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: Busy_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet Busy_SUT.c usage_Busy_Sleep_Wakeup
*******************************************************************************/
void Busy_Sleep(void)
{
    #if defined(Busy__PC)
        Busy_backup.pcState = Busy_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            Busy_backup.usbState = Busy_CR1_REG;
            Busy_USB_POWER_REG |= Busy_USBIO_ENTER_SLEEP;
            Busy_CR1_REG &= Busy_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Busy__SIO)
        Busy_backup.sioState = Busy_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        Busy_SIO_REG &= (uint32)(~Busy_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: Busy_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to Busy_Sleep() for an example usage.
*******************************************************************************/
void Busy_Wakeup(void)
{
    #if defined(Busy__PC)
        Busy_PC = Busy_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            Busy_USB_POWER_REG &= Busy_USBIO_EXIT_SLEEP_PH1;
            Busy_CR1_REG = Busy_backup.usbState;
            Busy_USB_POWER_REG &= Busy_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Busy__SIO)
        Busy_SIO_REG = Busy_backup.sioState;
    #endif
}


/* [] END OF FILE */
