/*******************************************************************************
* File Name: main.c
*
* Version: 1.0
*
* Description:
*  This example project demonstrates the use of an SCB-based SPI master
*  component. The SCB SPI master communicates with a UDB-based SPI slave,
*  located on the same PSoC but wired together externally. The SPI slave
*  receives a packet with a command from the SPI master to control the
*  RGB LED color. Once the slave updates the LED color, it returns a status
*  packet to the master.
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#include <main.h>

/* SPIM functions */
static void SPIM_SendCommandPacket(void);
static uint32 SPIM_ReadStatusPacket(void);

/* This dummy buffer used by SPIM when it receives status packet.
* This dummy buffer used by SPIS when it receives command packet.
*/
const uint8 dummyBuffer[31] = {0x00};


/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
*  The main function performs the following actions:
*   1. Turns off RGB LED.
*   2. Sets up SPIS and SPIM components.
*   3. Enables global interrupts.
*   4. SPI master (SPIM) sends command to the SPI slave (SPIS) to control
*      RGB LED.
*   5. SPIS receives the command, updates the LED and returns a status packet.
*   6. SPIM receives the response status packet. If successful, increment to
*      next command. Otherwise send the same command until successful.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
int main()
{
    SPIM_Start();   
   
    /*Enale the Display: Active Low */
    Enable_Write(0u);
    
    CyDelay(60);
    
    /* Wait for the display to be free */
    while(!Busy_Read()) CyDelay(1);
    
    CyGlobalIntEnable;

    /* Send packet with command to the slave */
    SPIM_SendCommandPacket();
    
    SPIM_ReadStatusPacket();
    
    return 0;
}


/*******************************************************************************
* Function Name: SPIM_SendCommandPacket
********************************************************************************
* Summary:
*  SPIM initiates the transmission of a command packet to the SPIS. After
*  transfer completion, the dummy bytes sent by the SPIS are cleared from the
*  RX buffer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
static void SPIM_SendCommandPacket(void)
{
    /* SPIM TX buffer */
    static uint8 mTxBuffer[] = {0x30, 0x01, 0x01, 0x00};

    /* Wait for the display to be free */
    while(!Busy_Read()) CyDelay(1);

    /* Start transfer */
    SPIM_SpiUartPutArray(mTxBuffer, 4);

    /* Wait for the end of the transfer. The number of transmitted data
    * elements has to be equal to the number of received data elements.
    */
    while(4 != SPIM_SpiUartGetRxBufferSize())
    {
    }

    /* Clear dummy bytes from RX buffer */
    SPIM_SpiUartClearRxBuffer();
}


/*******************************************************************************
* Function Name: SPIM_ReadStatusPacket
********************************************************************************
* Summary:
*  SPIM initiates the transmission of a dummy packet to collect the status
*  information from the SPIS. After the transfer is complete the format of
*  the packet is verified and the status is returned. If the format of the
*  packet is invalid the unknown status is returned.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
static uint32 SPIM_ReadStatusPacket(void)
{
    uint8 tmpBuffer[PACKET_SIZE] = {0};
    uint32 i;
    
    /* Wait for the display to be free */
    while(!Busy_Read()) CyDelay(1);    

    /* Start transfer */
    SPIM_SpiUartPutArray(dummyBuffer, PACKET_SIZE);
    
    /* Wait for the end of the transfer. The number of transmitted data
    * elements has to be equal to the number of received data elements.
    */
    while (PACKET_SIZE != SPIM_SpiUartGetRxBufferSize())
    {
    }

    /* Clear dummy bytes from TX buffer */
    SPIM_SpiUartClearTxBuffer();

    /* Read data from the RX buffer */
    i = 0u;
    while (0u != SPIM_SpiUartGetRxBufferSize())
    {
        tmpBuffer[i] = (uint8)SPIM_SpiUartReadRxData();
        i++;
    }

    return 1;
}

/* [] END OF FILE */
